@@ -81,9 +81,7 @@ config_defaults = {
         "show_lengths_cell": True,
         "show_lengths_edit": True,
         "stretch_length": 0.05,
-        "undo_limit": 50,
         "use_custom_font": False,
-        "use_undo_limit": False,
         "use_zebra_stripes": True,
         "visible_fields": [gaupol.fields.NUMBER,
                            gaupol.fields.START,
@@ -104,9 +102,8 @@ config_defaults = {
     "file": {
         "align_method": aeidon.align_methods.POSITION,
         "directory": "",
-        "encoding": aeidon.util.get_default_encoding() or "utf_8",
+        "encoding": "utf_8",
         "format": aeidon.formats.SUBRIP,
-        "max_recent": 10,
         "newline": aeidon.util.get_default_newline(),
         },
     "framerate_convert": {
@@ -134,9 +131,6 @@ config_defaults = {
         "use_skip_max_lines": True,
         },
     "output_window": {
-        "maximized": False,
-        "position": [0, 0],
-        "show": False,
         "size": [600, 371],
         },
     "position_shift": {
@@ -157,14 +151,13 @@ config_defaults = {
     "search": {
         "fields": [gaupol.fields.MAIN_TEXT],
         "ignore_case": True,
-        "max_history": 10,
         "regex": False,
         "target": gaupol.targets.CURRENT,
         },
     "spell_check": {
         "field": gaupol.fields.MAIN_TEXT,
         "inline": False,
-        "language": aeidon.locales.get_system_code() or "en",
+        "language": "en",
         "target": gaupol.targets.CURRENT,
         },
     "subtitle_insert": {
@@ -396,9 +389,10 @@ class ConfigurationStore(gaupol.AttributeDictionary):
             # Ignore all decoding errors, since all keys and all standard
             # values are all ASCII. This will only mangle recent etc.
             # filenames, which are always checked for existance anyway.
-            lines = open(self.path, "r",
-                         encoding=encoding,
-                         errors="ignore").readlines()
+            with open(self.path, "r",
+                      encoding=encoding,
+                      errors="ignore") as f:
+                lines = f.readlines()
 
         except IOError:
             aeidon.util.print_read_io(sys.exc_info(), self.path)
@@ -481,12 +475,8 @@ class ConfigurationStore(gaupol.AttributeDictionary):
         """
         if self.path is None: return
         self.general.version = gaupol.__version__
-        if not os.path.isdir(os.path.dirname(self.path)):
-            try:
-                aeidon.util.makedirs(os.path.dirname(self.path))
-            except (IOError, OSError):
-                aeidon.util.print_write_io(sys.exc_info(), self.path)
-                raise # IOError, OSError
+        with aeidon.util.silent(OSError):
+            aeidon.util.makedirs(os.path.dirname(self.path))
         encoding = aeidon.util.get_default_encoding()
         try:
             f = open(self.path, "w", encoding=encoding)
@@ -516,3 +506,5 @@ class ConfigurationStore(gaupol.AttributeDictionary):
                            "to configuration file '{}'."
                            .format(value, section, option, self.path)),
                           file=sys.stderr)
+
+        f.close()
