@@ -251,7 +251,7 @@ class VideoPlayer(aeidon.Observable):
         """Handle error message from the bus."""
         title, message = message.parse_error()
         dialog = gaupol.ErrorDialog(None, title, message)
-        dialog.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+        dialog.add_button(_("_OK"), Gtk.ResponseType.OK)
         dialog.set_default_response(Gtk.ResponseType.OK)
         gaupol.util.flash_dialog(dialog)
 
@@ -367,7 +367,7 @@ class VideoPlayer(aeidon.Observable):
         """
         self._playbin.props.uri = uri
         # XXX: We need platform-specific calls here.
-        self._xid = self.widget.props.window.get_xid()
+        self._xid = self.widget.get_window().get_xid()
         self.subtitle_text = ""
         try:
             # Find out the exact framerate to be able
